//-----------------------------------------------------------------------
// Copyright (c) 2017 Snap Inc.
//-----------------------------------------------------------------------
#define SC_USE_USER_DEFINED_VS_MAIN

#include <required.glsl>

#ifndef sc_GaussianFilterDataLength
#define sc_GaussianFilterDataLength 5
#endif // sc_GaussianFilterDataLength

#if (sc_GaussianFilterDataLength * 2 - 1 > sc_MaxVaryingVec4 * 2)
#error This device not supporting requested gaussian filter
#endif

uniform sampler2D targetTexture;
uniform float gaussianFilterWeights[sc_GaussianFilterDataLength];
uniform float gaussianFilterOffsets[sc_GaussianFilterDataLength];

varying vec2 varTexCoords[sc_GaussianFilterDataLength * 2 - 1];

#ifdef VERTEX_SHADER
attribute vec2 position;

void main(void) {
    vec2 texCoords = position * 0.5 + 0.5;
    varTexCoords[0] = texCoords;
    
    for (int index = 0; index < sc_GaussianFilterDataLength - 1; index++) {
#ifdef sc_GaussianFilterVerticalPass
        varTexCoords[index * 2 + 1] = texCoords + vec2(0.0, gaussianFilterOffsets[index + 1]);
        varTexCoords[index * 2 + 2] = texCoords - vec2(0.0, gaussianFilterOffsets[index + 1]);
#else
        varTexCoords[index * 2 + 1] = texCoords + vec2(gaussianFilterOffsets[index + 1], 0.0);
        varTexCoords[index * 2 + 2] = texCoords - vec2(gaussianFilterOffsets[index + 1], 0.0);
#endif // sc_GaussianFilterVerticalPass
    }
    
    gl_Position = vec4(position, 0.0, 1.0);
}
#endif // VERTEX_SHADER

#ifdef FRAGMENT_SHADER
void main(void) {
    vec4 result = texture2D(targetTexture, varTexCoords[0]) * gaussianFilterWeights[0];
    
    for (int index = 0; index < sc_GaussianFilterDataLength - 1; index++) {
        result += (texture2D(targetTexture, varTexCoords[index * 2 + 1]) + texture2D(targetTexture, varTexCoords[index * 2 + 2])) * gaussianFilterWeights[index + 1];
    }
    
    gl_FragColor = result;
}
#endif // FRAGMENT_SHADER
